Spaken
======

Spaken is a tool to optimize ci/cd workflows for Python applications. It does
this by collecting all the dependencies (python packages) and convert them to
wheel files to store on AWS S3.

.. image:: docs/demo.gif
